@@ -23,7 +23,7 @@
 #include "kimap_debug.h"
 
 #include "metadatajobbase_p.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
@@ -58,7 +58,7 @@ GetMetaDataJob::~GetMetaDataJob()
 static QList<QByteArray> sort(const QSet<QByteArray> &set)
 {
     QList<QByteArray> sortedEntries = set.toList();
-    qSort(sortedEntries);
+    std::sort(sortedEntries.begin(), sortedEntries.end());
     return sortedEntries;
 }
 
@@ -127,7 +127,7 @@ void GetMetaDataJob::doStart()
 //  qCDebug(KIMAP_LOG) << "SENT: " << command << " " << parameters;
 }
 
-void GetMetaDataJob::handleResponse(const Message &response)
+void GetMetaDataJob::handleResponse(const Response &response)
 {
     Q_D(GetMetaDataJob);
 //  qCDebug(KIMAP_LOG) << "GOT: " << response.toString();
@@ -262,8 +262,11 @@ QHash<QString, QMap<QByteArray, QByteArray> > GetMetaDataJob::allMetaDataForMail
 {
     Q_D(const GetMetaDataJob);
     QHash<QString, QMap<QByteArray, QByteArray> > mailboxHash;
-    Q_FOREACH (const QString &mailbox, d->metadata.keys()) {
-        mailboxHash.insert(mailbox, allMetaDataForMailbox(mailbox));
+
+    QMapIterator<QString, QMap<QByteArray, QMap<QByteArray, QByteArray> > > i(d->metadata);
+    while (i.hasNext()) {
+        i.next();
+        mailboxHash.insert(i.key(), allMetaDataForMailbox(i.key()));
     }
     return mailboxHash;
 }
