@@ -17,20 +17,20 @@
     02110-1301, USA.
 */
 
-#ifndef KIMAP2_UNSUBSCRIBEJOB_H
-#define KIMAP2_UNSUBSCRIBEJOB_H
+#ifndef KIMAP_UNSUBSCRIBEJOB_H
+#define KIMAP_UNSUBSCRIBEJOB_H
 
-#include "kimap2_export.h"
+#include "kimap_export.h"
 
 #include "job.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 
 class Session;
 class UnsubscribeJobPrivate;
 
-class KIMAP2_EXPORT UnsubscribeJob : public Job
+class KIMAP_EXPORT UnsubscribeJob : public Job
 {
     Q_OBJECT
     Q_DECLARE_PRIVATE(UnsubscribeJob)
@@ -39,13 +39,13 @@ class KIMAP2_EXPORT UnsubscribeJob : public Job
 
 public:
     explicit UnsubscribeJob(Session *session);
-    virtual ~UnsubscribeJob();
+    ~UnsubscribeJob() override;
 
     void setMailBox(const QString &mailBox);
     QString mailBox() const;
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
 };
 
 }
